%define _disable_ld_no_undefined 1

# We are not going to build the URW fonts because of license reasons
%define gsverdir %(echo %{version}|sed -e 's/\\.//g')

%define bootstrap 0

Summary:	PostScript, PDF and XPS interpreter and renderer
Name:		ghostpcl
Version:	10.03.0
Release:	%mkrel 3
License:	AGPLv3+
Group:		System/Printing
Source0:	https://github.com/ArtifexSoftware/ghostpdl-downloads/releases/download/gs%gsverdir/ghostpdl-%{version}.tar.gz
Source1:	gpcl6-wrapper

# Don't define static openjpeg2, breaks linking
Patch0: ghostscript-9.51-openjpeg2-non-static.patch
# Fix some shell scripts
Patch1: ghostscript-scripts.patch
# Build igcref.c with -O0 to work around bug #150771.
Patch2: ghostscript-noopt.patch
# Define .runlibfileifexists.
Patch3: ghostscript-runlibfileifexists.patch
# Restored Fontmap.local patch, incorrectly dropped after
# ghostscript-8.15.4-3 (bug #610301).
# Note: don't use -b here to avoid the backup file ending up in the
# package manifest.
Patch4: ghostscript-Fontmap.local.patch

%if !%{bootstrap}
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	cups-devel
BuildRequires:	pkgconfig(fontconfig)
%endif
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	libtool
BuildRequires:	unzip
BuildRequires:	gettext-devel
BuildRequires:	glibc-devel
BuildRequires:	jbig2dec-devel
BuildRequires:	pkgconfig(expat)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	libpaper-devel
BuildRequires:	netpbm-devel
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(ice)
BuildRequires:	pkgconfig(jasper)
BuildRequires:	pkgconfig(lcms2) >= 2.5
BuildRequires:	pkgconfig(libidn)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(sm)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xt)
BuildRequires:	pkgconfig(zlib)

Requires:	fonts-ttf-urw
Requires:	gv

%description
GhostPCL is Artifex Software's implementation of the PCL-5(TM) and
PCL-XL(TM) family of page description languages. For more information
please see the documentation included with the source package.

GhostPDL is PCL technology; it is not intended to be a finished software
application but a collection of software components that will ultimately be
included in a software application or a real time embedded system. Generally
the GhostPDL languages are compliant with the Genoa (now QualityLogic)
Functional Test Suite and the Genoa Application Test suite. Also each
language should run the corresponding Genoa Comprehensive Evaluation Test
(CET) without egregious errors.



%prep
%setup -q -n ghostpdl-%{version}
rm -rf expat freetype icclib jasper lcms2 libpng openjpeg zlib cups/libs
%autopatch -p1

# Don't ship backup files
find . -name "*.*~" |xargs rm -f

# prevent building and using bundled libs
rm -rf jasper jbig2dec libpng expat zlib lcms* freetype jpeg tiff

%build
%global optflags %(echo "%{optflags} -Wno-incompatible-pointer-types -Wno-int-conversion")

autoreconf -vfi

%configure \
%if !%{bootstrap}
	--enable-fontconfig \
%endif
%ifarch %{ix86}
	--disable-sse2 \
%endif
%ifarch %{arm}
	--without-tesseract \
%endif
	--without-ijs \
	--with-x \
	--disable-compile-inits \
	--without-gs

%make_build XCFLAGS="%{optflags}"

%{__sed} -e "s#@GHOSTPCLDIR@#%{_libexecdir}/%{name}#" %{SOURCE1} > gpcl6

%install
install -d -m755 %{buildroot}%{_bindir}
install -m755 gpcl6 pcl/tools/pcl2pdfwr bin/gxps %{buildroot}%{_bindir}

install -d -m755 %{buildroot}%{_libexecdir}/%{name}
install -m755 bin/gpcl6 %{buildroot}%{_libexecdir}/%{name}
ln -s %{_datadir}/fonts/TTF/fonts-ttf-urw %{buildroot}%{_libexecdir}/%{name}/urwfonts

%files
%doc doc
%license LICENSE
%{_bindir}/*
%{_libexecdir}/%{name}/


%changelog
* Tue Apr 02 2024 ns80 <ns80> 10.03.0-3.mga10
+ Revision: 2053928
- fix build with GCC14

* Fri Mar 08 2024 ns80 <ns80> 10.03.0-2.mga10
+ Revision: 2048753
- fix armv7hl build

* Thu Mar 07 2024 ns80 <ns80> 10.03.0-1.mga10
+ Revision: 2048376
- new version 10.03.0

* Fri Nov 03 2023 ns80 <ns80> 10.02.1-1.mga10
+ Revision: 2003764
- new version 10.02.1

* Wed Sep 20 2023 ns80 <ns80> 10.02.0-2.mga10
+ Revision: 1988467
- correct gpcl6-wrapper (mga#32260)

* Fri Sep 15 2023 ns80 <ns80> 10.02.0-1.mga10
+ Revision: 1986832
- new version 10.02.0

* Thu Sep 07 2023 ns80 <ns80> 10.01.2-2.mga10
+ Revision: 1985003
- add upstream patch for CVE-2023-38560

* Wed Aug 30 2023 ns80 <ns80> 10.01.2-1.mga10
+ Revision: 1981715
- new version 10.01.2

* Mon Dec 12 2022 ns80 <ns80> 10.0.0-2.mga9
+ Revision: 1921032
- rebuild for new libtiff

* Fri Sep 23 2022 ns80 <ns80> 10.0.0-1.mga9
+ Revision: 1891747
- new version 10.0.0

* Tue Apr 12 2022 ns80 <ns80> 9.56.1-1.mga9
+ Revision: 1849010
- new version 9.56.1

* Fri Apr 01 2022 umeabot <umeabot> 9.55.0-2.mga9
+ Revision: 1839301
- Mageia 9 Mass Rebuild

* Mon Oct 11 2021 ns80 <ns80> 9.55.0-1.mga9
+ Revision: 1750551
- new version 9.55

* Thu Apr 01 2021 ns80 <ns80> 9.54.0-2.mga9
+ Revision: 1712415
- also build for aarch64

* Thu Apr 01 2021 ns80 <ns80> 9.54.0-1.mga9
+ Revision: 1712410
- new version 9.54.0

* Fri Oct 23 2020 akien <akien> 9.53.3-2.mga8
+ Revision: 1638988
- Fix FTBFS with freetype 2.10.3+

* Thu Oct 01 2020 ns80 <ns80> 9.53.3-1.mga8
+ Revision: 1631451
- new version 9.53.3

* Mon Sep 28 2020 daviddavid <daviddavid> 9.53.2-1.mga8
+ Revision: 1630946
- new version: 9.53.2

* Wed Sep 16 2020 daviddavid <daviddavid> 9.53.1-1.mga8
+ Revision: 1626874
- new version: 9.53.1

* Fri Aug 07 2020 ns80 <ns80> 9.52-2.mga8
+ Revision: 1611743
- add upstream patch for CVE-2020-15900 (mga#27037)

* Sun Mar 22 2020 ns80 <ns80> 9.52-1.mga8
+ Revision: 1558946
- new version 9.52

* Sat Mar 14 2020 ns80 <ns80> 9.51-1.mga8
+ Revision: 1556400
- new version 9.51

* Tue Feb 18 2020 umeabot <umeabot> 9.50-5.mga8
+ Revision: 1541109
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Dec 19 2019 ns80 <ns80> 9.50-4.mga8
+ Revision: 1469002
- another fix for wrapper script when a path contains spaces

* Thu Dec 19 2019 ns80 <ns80> 9.50-3.mga8
+ Revision: 1468899
- fix wrapper script when a path contains spaces

* Wed Dec 18 2019 ns80 <ns80> 9.50-2.mga8
+ Revision: 1468726
- add a wrapper for gpcl6 to solve the "Fonts not found" issue

* Thu Nov 28 2019 ns80 <ns80> 9.50-1.mga8
+ Revision: 1463347
- sync ghostpcl with ghostscript

* Sun Sep 23 2018 umeabot <umeabot> 9.05-9.mga7
+ Revision: 1297879
- Mageia 7 Mass Rebuild

* Tue Jun 19 2018 wally <wally> 9.05-8.mga7
+ Revision: 1238173
- fix build on aarch64

* Wed Sep 13 2017 cjw <cjw> 9.05-7.mga7
+ Revision: 1153479
- fix passing of optflags to make

* Mon Feb 08 2016 umeabot <umeabot> 9.05-6.mga6
+ Revision: 943470
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 9.05-5.mga5
+ Revision: 748039
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 9.05-4.mga5
+ Revision: 679560
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 9.05-3.mga4
+ Revision: 505915
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 spuhler <spuhler> 9.05-2.mga3
+ Revision: 353741
- reverted to 9.05
- upgrade to 9.06
  cleaned spec file
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Feb 16 2012 spuhler <spuhler> 9.05-1.mga2
+ Revision: 209573
- imported package ghostpcl

